@@ -45,10 +45,6 @@
 #include <libgnomeui/gnome-rr.h>
 #include <libgnomeui/gnome-rr-labeler.h>
 
-#ifdef HAVE_X11_EXTENSIONS_XRANDR_H
-#include <X11/extensions/Xrandr.h>
-#endif
-
 #ifdef HAVE_LIBNOTIFY
 #include <libnotify/notify.h>
 #endif
@@ -485,19 +481,12 @@ gsd_xrandr_manager_2_apply_configuration (GsdXrandrManager *manager,
 #include "gsd-xrandr-manager-glue.h"
 
 static gboolean
-is_laptop (GnomeOutputInfo *output)
+is_laptop (GnomeRRScreen *screen, GnomeOutputInfo *output)
 {
-        const char *output_name = output->name;
+        GnomeRROutput *rr_output;
 
-        if (output->connected && output_name &&
-            (strstr (output_name, "lvds")	||
-             strstr (output_name, "LVDS")	||
-             strstr (output_name, "Lvds")))
-        {
-                return TRUE;
-        }
-
-        return FALSE;
+        rr_output = gnome_rr_screen_get_output_by_name (screen, output->name);
+        return gnome_rr_output_is_laptop (rr_output);
 }
 
 static gboolean
@@ -696,13 +685,11 @@ make_laptop_setup (GnomeRRScreen *screen)
         for (i = 0; result->outputs[i] != NULL; ++i) {
                 GnomeOutputInfo *info = result->outputs[i];
 
-                if (is_laptop (info)) {
-                        if (!info->on) {
-                                if (!turn_on (screen, info, 0, 0)) {
-                                        gnome_rr_config_free (result);
-                                        result = NULL;
-                                        break;
-                                }
+                if (is_laptop (screen, info)) {
+                        if (!turn_on (screen, info, 0, 0)) {
+                                gnome_rr_config_free (result);
+                                result = NULL;
+                                break;
                         }
                 }
                 else {
@@ -722,14 +709,8 @@ make_laptop_setup (GnomeRRScreen *screen)
 static int
 turn_on_and_get_rightmost_offset (GnomeRRScreen *screen, GnomeOutputInfo *info, int x)
 {
-        if (info->on) {
-                info->x = x;
-                info->y = 0;
+        if (turn_on (screen, info, x, 0))
                 x += info->width;
-        } else {
-                if (turn_on (screen, info, x, 0))
-                        x += info->width;
-        }
 
         return x;
 }
@@ -748,14 +729,14 @@ make_xinerama_setup (GnomeRRScreen *screen)
         for (i = 0; result->outputs[i] != NULL; ++i) {
                 GnomeOutputInfo *info = result->outputs[i];
 
-                if (is_laptop (info))
+                if (is_laptop (screen, info))
                         x = turn_on_and_get_rightmost_offset (screen, info, x);
         }
 
         for (i = 0; result->outputs[i] != NULL; ++i) {
                 GnomeOutputInfo *info = result->outputs[i];
 
-                if (info->connected && !is_laptop (info))
+                if (info->connected && !is_laptop (screen, info))
                         x = turn_on_and_get_rightmost_offset (screen, info, x);
         }
 
@@ -777,13 +758,12 @@ make_other_setup (GnomeRRScreen *screen)
         for (i = 0; result->outputs[i] != NULL; ++i) {
                 GnomeOutputInfo *info = result->outputs[i];
 
-                if (is_laptop (info)) {
+                if (is_laptop (screen, info)) {
                         info->on = FALSE;
                 }
                 else {
-                        if (info->connected && !info->on) {
+                        if (info->connected)
                                 turn_on (screen, info, 0, 0);
-                        }
                }
         }
 
@@ -1028,7 +1008,7 @@ handle_fn_f7 (GsdXrandrManager *mgr, guint32 timestamp)
 }
 
 static GnomeOutputInfo *
-get_laptop_output_info (GnomeRRConfig *config)
+get_laptop_output_info (GnomeRRScreen *screen, GnomeRRConfig *config)
 {
         int i;
 
@@ -1036,7 +1016,7 @@ get_laptop_output_info (GnomeRRConfig *config)
                 GnomeOutputInfo *info;
 
                 info = config->outputs[i];
-                if (is_laptop (info))
+                if (is_laptop (screen, info))
                         return info;
         }
 
@@ -1108,7 +1088,7 @@ handle_rotate_windows (GsdXrandrManager *mgr, guint32 timestamp)
 
         current = gnome_rr_config_new_current (screen);
 
-        rotatable_output_info = get_laptop_output_info (current);
+        rotatable_output_info = get_laptop_output_info (screen, current);
         if (rotatable_output_info == NULL) {
                 g_debug ("No laptop outputs found to rotate; XF86RotateWindows key will do nothing");
                 goto out;
